package de.tu_darmstadt.tk.SmartHomeNetworkSim.view;

import java.awt.FlowLayout;

import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;

import de.tu_darmstadt.tk.SmartHomeNetworkSim.control.Controller;
import de.tu_darmstadt.tk.SmartHomeNetworkSim.core.Model;
import de.tu_darmstadt.tk.SmartHomeNetworkSim.view.popups.SimulationConfigurator;

/**
 * MenuBar for the MainFrame, which contains the different items like options
 *
 * @author Andreas T. Meyer-Berg
 */
public class MenuBar extends JMenuBar {

	/**
	 * Model
	 */
	Model model;
	/**
	 * Controller to manipulate the model
	 */
	Controller controller;
	
	/**
	 * JMenu for the Simulation
	 */
	JMenu mntmSimulation;
	
	/**
	 * JMenu for Editing of Devices, Options etc. 
	 */
	JMenu mnEdit;
	
	/**
	 * JMenu for help with the program
	 */
	JMenu mntmHelp;
	
	/**
	 * Serial Version
	 */
	private static final long serialVersionUID = 4293499386792032777L;
	
	/**
	 * Initialize the Menu Bar, add all the items and add the different actions
	 * @param model Model
	 * @param controller Controller
	 */
	public MenuBar(Model model, Controller controller) {
		this.model = model;
		this.controller = controller;
		
		this.setLayout(new FlowLayout(FlowLayout.LEADING));

		initializeSimulationMenu();
		this.add(mntmSimulation);
		initializeEditMenu();
		this.add(mnEdit);
		initializeHelpMenu();
		this.add(mntmHelp);
	}
	
	/**
	 * Initializes the Simulation Menu
	 */
	private void initializeSimulationMenu(){
		mntmSimulation = new JMenu("Simulation");
		JMenuItem mntmConfigureSim = new JMenuItem("Configure Sim");
		mntmConfigureSim.addActionListener(a->{
			SimulationConfigurator sim = new SimulationConfigurator(this.model.getSim());
			sim.setLocationRelativeTo(this.getParent());
			sim.setVisible(true);
		});
		mntmSimulation.add(mntmConfigureSim);		
	}
	
	/**
	 * Initializes the Edit Menu
	 */
	private void initializeEditMenu() {
		mnEdit = new JMenu("Edit");
		JMenuItem mntmOption = new JMenuItem("Options");
		mnEdit.add(mntmOption);
	}
	
	/**
	 * Initializes the Help Menu
	 */
	private void initializeHelpMenu() {
		mntmHelp = new JMenu("Help");
	}
}
